summaryrefslogtreecommitdiff
path: root/board/aurash/fw_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'board/aurash/fw_config.h')
-rw-r--r--board/aurash/fw_config.h34
1 files changed, 23 insertions, 11 deletions
diff --git a/board/aurash/fw_config.h b/board/aurash/fw_config.h
index c2afd4c603..e498831966 100644
--- a/board/aurash/fw_config.h
+++ b/board/aurash/fw_config.h
@@ -3,25 +3,32 @@
* found in the LICENSE file.
*/
-#ifndef __BOARD_BRASK_FW_CONFIG_H_
-#define __BOARD_BRASK_FW_CONFIG_H_
+#ifndef __BOARD_AURASH_FW_CONFIG_H_
+#define __BOARD_AURASH_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Brask board.
*
* Source of truth is the project/brask/brask/config.star configuration file.
*/
-enum ec_cfg_audio_type { DB_AUDIO_UNKNOWN = 0, DB_NAU88L25B_I2S = 1 };
-enum ec_cfg_bj_power { BJ_135W = 0, BJ_230W = 1 };
+enum ec_cfg_bj_power { BJ_90W = 0, BJ_135W = 1 };
-union brask_cbi_fw_config {
+enum ec_cfg_power_on_monitor {
+ POWER_ON_MONITOR_ENABLE = 0,
+ POWER_ON_MONITOR_DISABLE = 1
+};
+
+union aurash_cbi_fw_config {
struct {
- uint32_t audio : 3;
uint32_t bj_power : 2;
- uint32_t reserved_1 : 27;
+ uint32_t mlb_usb_tbt : 2;
+ uint32_t storage : 2;
+ uint32_t audio : 1;
+ enum ec_cfg_power_on_monitor po_mon : 1;
+ uint32_t reserved_1 : 24;
};
uint32_t raw_value;
};
@@ -31,11 +38,16 @@ union brask_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union brask_cbi_fw_config get_fw_config(void);
+union aurash_cbi_fw_config get_fw_config(void);
/**
* Get the barrel-jack power from FW_CONFIG.
*/
void ec_bj_power(uint32_t *voltage, uint32_t *current);
-#endif /* __BOARD_BRASK_FW_CONFIG_H_ */
+/**
+ * Get enable/disable power on by monitor from FW_CONFIG.
+ */
+enum ec_cfg_power_on_monitor ec_cfg_power_on_monitor(void);
+
+#endif /* __BOARD_AURASH_FW_CONFIG_H_ */
@@ -3,25 +3,32 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Brask board.
+ * CBI FW_CONFIG layout for Aurash board.
*
@@ -3,25 +3,32 @@
*
- * Source of truth is the project/brask/brask/config.star configuration file.
+ * Source of truth is the project/brask/aurash/config.star configuration file.
*/